@@ -28,7 +28,6 @@
 #include <QSignalSpy>
 #include <QStandardPaths>
 #include <QTest>
-#include <QToolButton>
 
 #include <ktoolbar.h>
 #include <kmainwindow.h>
@@ -43,7 +42,7 @@ Q_DECLARE_METATYPE(Qt::MouseButtons)
 Q_DECLARE_METATYPE(Qt::KeyboardModifiers)
 
 // Ensure everything uses test paths, including stuff run before main, such as the KdePlatformThemePlugin
-void enableTestMode() { QStandardPaths::enableTestMode(true); }
+void enableTestMode() { QStandardPaths::setTestModeEnabled(true); }
 Q_CONSTRUCTOR_FUNCTION(enableTestMode)
 
 class tst_KToolBar : public QObject
@@ -75,7 +74,7 @@ Q_SIGNALS:
     void signalAppearanceChanged();
 
 protected:
-    bool eventFilter(QObject *watched, QEvent *event) Q_DECL_OVERRIDE;
+    bool eventFilter(QObject *watched, QEvent *event) override;
 
 private:
     void changeGlobalIconSizeSetting(int, int);
@@ -108,7 +107,7 @@ void tst_KToolBar::initTestCase()
 {
     // start with a clean place to put data
     QDir testDataDir = QDir(QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation));
-    QVERIFY(testDataDir.absolutePath().contains(QStringLiteral("qttest")));
+    QVERIFY(testDataDir.absolutePath().contains(QLatin1String("qttest")));
     testDataDir.removeRecursively();
     testDataDir.mkpath(QStringLiteral("."));
 
@@ -159,7 +158,7 @@ void tst_KToolBar::cleanupTestCase()
 {
     QDir testDataDir = QDir(QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation));
     QDir testIconsDir = QDir(testDataDir.absoluteFilePath(QStringLiteral("icons")));
-    QVERIFY(testIconsDir.absolutePath().contains(QStringLiteral("qttest")));
+    QVERIFY(testIconsDir.absolutePath().contains(QLatin1String("qttest")));
     testIconsDir.removeRecursively();
 }
 
@@ -324,7 +323,7 @@ void tst_KToolBar::testIconSizeXmlGui()
         // was it the default size? (for the main toolbar, we only check that one)
         const bool usingDefaultSize = iconSize == KIconLoader::global()->currentSize(KIconLoader::MainToolbar);
         if (usingDefaultSize) {
-            QVERIFY(!group.groupList().contains(QStringLiteral("Toolbar mainToolBar")));
+            QVERIFY(!group.groupList().contains(QLatin1String("Toolbar mainToolBar")));
             QVERIFY(!group.group("Toolbar mainToolBar").hasKey("IconSize"));
         } else {
             QVERIFY(group.group("Toolbar mainToolBar").hasKey("IconSize"));
