@@ -25,10 +25,8 @@
 #include <QAction>
 #include <QDialogButtonBox>
 #include <QDomDocument>
-#include <QLayout>
 #include <QDir>
 #include <QFile>
-#include <QHeaderView>
 #include <QToolButton>
 #include <QLabel>
 #include <QApplication>
@@ -55,8 +53,10 @@
 #include "../kxmlgui_version.h"
 
 static const char separatorstring[] = I18N_NOOP("--- separator ---");
+static const char spacerstring[] = I18N_NOOP("--- expanding spacer ---");
 
 #define SEPARATORSTRING i18n(separatorstring)
+#define SPACERSTRING i18n(spacerstring)
 
 //static const char *const s_XmlTypeToString[] = { "Shell", "Part", "Local", "Merged" };
 
@@ -73,12 +73,12 @@ static ToolBarList findToolBars(const QDomElement &start)
     ToolBarList list;
 
     for (QDomElement elem = start; !elem.isNull(); elem = elem.nextSiblingElement()) {
-        if (elem.tagName() == QStringLiteral("ToolBar")) {
+        if (elem.tagName() == QLatin1String("ToolBar")) {
             if (elem.attribute(QStringLiteral("noEdit")) != QLatin1String("true")) {
                 list.append(elem);
             }
         } else {
-            if (elem.tagName() != QStringLiteral("MenuBar")) { // there are no toolbars inside the menubar :)
+            if (elem.tagName() != QLatin1String("MenuBar")) { // there are no toolbars inside the menubar :)
                 list += findToolBars(elem.firstChildElement());    // recursive
             }
         }
@@ -172,7 +172,7 @@ QString XmlData::toolBarText(const QDomElement &it) const
     if ((m_type == XmlData::Shell) ||
             (m_type == XmlData::Part)) {
         QString doc_name(m_document.documentElement().attribute(QStringLiteral("name")));
-        name += QStringLiteral(" <") + doc_name + QLatin1Char('>');
+        name += QLatin1String(" <") + doc_name + QLatin1Char('>');
     }
     return name;
 }
@@ -188,6 +188,7 @@ public:
           m_internalName(name),
           m_statusText(statusText),
           m_isSeparator(false),
+          m_isSpacer(false),
           m_isTextAlongsideIconHidden(false)
     {
         // Drop between items, not onto items
@@ -210,6 +211,10 @@ public:
     {
         m_isSeparator = sep;
     }
+    void setSpacer(bool spacer)
+    {
+        m_isSpacer = spacer;
+    }
     void setTextAlongsideIconHidden(bool hidden)
     {
         m_isTextAlongsideIconHidden = hidden;
@@ -230,6 +235,10 @@ public:
     {
         return m_isSeparator;
     }
+    bool isSpacer() const
+    {
+        return m_isSpacer;
+    }
     bool isTextAlongsideIconHidden() const
     {
         return m_isTextAlongsideIconHidden;
@@ -245,6 +254,7 @@ private:
     QString m_internalName;
     QString m_statusText;
     bool m_isSeparator;
+    bool m_isSpacer;
     bool m_isTextAlongsideIconHidden;
 };
 
@@ -254,6 +264,7 @@ static QDataStream &operator<< (QDataStream &s, const ToolBarItem &item)
     s << item.internalName();
     s << item.statusText();
     s << item.isSeparator();
+    s << item.isSpacer();
     s << item.isTextAlongsideIconHidden();
     return s;
 }
@@ -271,6 +282,9 @@ static QDataStream &operator>> (QDataStream &s, ToolBarItem &item)
     bool sep;
     s >> sep;
     item.setSeparator(sep);
+    bool spacer;
+    s >> spacer;
+    item.setSpacer(spacer);
     bool hidden;
     s >> hidden;
     item.setTextAlongsideIconHidden(hidden);
@@ -337,7 +351,7 @@ IconTextEditDialog::IconTextEditDialog(QWidget *parent)
     setLayout(layout);
 
     QGridLayout *grid = new QGridLayout;
-    grid->setMargin(0);
+    grid->setContentsMargins(0, 0, 0, 0);
 
     m_lineEdit = new QLineEdit(this);
     m_lineEdit->setClearButtonEnabled(true);
@@ -447,7 +461,7 @@ public:
 
     QString xmlFile(const QString &xml_file) const
     {
-        return xml_file.isEmpty() ? m_componentName + QStringLiteral("ui.rc") : xml_file;
+        return xml_file.isEmpty() ? m_componentName + QLatin1String("ui.rc") : xml_file;
     }
 
     /**
@@ -693,10 +707,10 @@ void KEditToolBarPrivate::defaultClicked()
     } else {
         int slash = m_file.lastIndexOf(QLatin1Char('/')) + 1;
         if (slash) {
-            m_file = m_file.mid(slash);
+            m_file.remove(0, slash);
         }
         const QString xml_file = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) +
-            QStringLiteral("/kxmlgui5/") + QCoreApplication::instance()->applicationName() + QLatin1Char('/') + m_file;
+            QLatin1String("/kxmlgui5/") + QCoreApplication::instance()->applicationName() + QLatin1Char('/') + m_file;
 
         if (QFile::exists(xml_file))
             if (!QFile::remove(xml_file)) {
@@ -1082,7 +1096,7 @@ void KEditToolBarWidgetPrivate::setupLayout()
 
     // now start with our layouts
     QVBoxLayout *top_layout = new QVBoxLayout(m_widget);
-    top_layout->setMargin(0);
+    top_layout->setContentsMargins(0, 0, 0, 0);
 
     QVBoxLayout *name_layout = new QVBoxLayout();
     QHBoxLayout *list_layout = new QHBoxLayout();
@@ -1175,6 +1189,7 @@ void KEditToolBarWidgetPrivate::loadToolBarCombo(const QString &defaultToolBar)
 void KEditToolBarWidgetPrivate::loadActions(const QDomElement &elem)
 {
     const QLatin1String tagSeparator("Separator");
+    const QLatin1String tagSpacer("Spacer");
     const QLatin1String tagMerge("Merge");
     const QLatin1String tagActionList("ActionList");
     const QLatin1String tagAction("Action");
@@ -1182,6 +1197,8 @@ void KEditToolBarWidgetPrivate::loadActions(const QDomElement &elem)
 
     int     sep_num = 0;
     QString sep_name(QStringLiteral("separator_%1"));
+    int     spacer_num = 0;
+    QString spacer_name(QStringLiteral("spacer_%1"));
 
     // clear our lists
     m_inactiveList->clear();
@@ -1214,6 +1231,13 @@ void KEditToolBarWidgetPrivate::loadActions(const QDomElement &elem)
             it.setAttribute(attrName, act->internalName());
             continue;
         }
+        if (it.tagName() == tagSpacer) {
+            ToolBarItem *act = new ToolBarItem(m_activeList, tagSpacer, spacer_name.arg(spacer_num++), QString());
+            act->setSpacer(true);
+            act->setText(SPACERSTRING);
+            it.setAttribute(attrName, act->internalName());
+            continue;
+        }
 
         if (it.tagName() == tagMerge) {
             // Merge can be named or not - use the name if there is one
@@ -1265,11 +1289,16 @@ void KEditToolBarWidgetPrivate::loadActions(const QDomElement &elem)
 
     m_inactiveList->sortItems(Qt::AscendingOrder);
 
-    // finally, add default separators to the inactive list
-    ToolBarItem *act = new ToolBarItem(nullptr, tagSeparator, sep_name.arg(sep_num++), QString());
-    act->setSeparator(true);
-    act->setText(SEPARATORSTRING);
-    m_inactiveList->insertItem(0, act);
+    // finally, add default separators and spacers to the inactive list
+    ToolBarItem *sep = new ToolBarItem(nullptr, tagSeparator, sep_name.arg(sep_num++), QString());
+    sep->setSeparator(true);
+    sep->setText(SEPARATORSTRING);
+    m_inactiveList->insertItem(0, sep);
+    
+    ToolBarItem *spacer = new ToolBarItem(nullptr, tagSpacer, spacer_name.arg(spacer_num++), QString());
+    spacer->setSpacer(true);
+    spacer->setText(SPACERSTRING);
+    m_inactiveList->insertItem(1, spacer);
 }
 
 KActionCollection *KEditToolBarWidget::actionCollection() const
@@ -1345,10 +1374,10 @@ void KEditToolBarWidgetPrivate::slotActiveSelectionChanged()
     m_removeAction->setEnabled(toolitem);
 
     m_changeIcon->setEnabled(toolitem &&
-                             toolitem->internalTag() == QStringLiteral("Action"));
+                             toolitem->internalTag() == QLatin1String("Action"));
 
     m_changeIconText->setEnabled(toolitem &&
-                                 toolitem->internalTag() == QStringLiteral("Action"));
+                                 toolitem->internalTag() == QLatin1String("Action"));
 
     if (toolitem) {
         m_upAction->setEnabled(toolitem->index() != 0);
@@ -1402,9 +1431,11 @@ void KEditToolBarWidgetPrivate::insertActive(ToolBarItem *item, ToolBarItem *bef
     }
 
     QDomElement new_item;
-    // let's handle the separator specially
+    // let's handle the separator and spacer specially
     if (item->isSeparator()) {
         new_item = m_widget->domDocument().createElement(QStringLiteral("Separator"));
+    } else if (item->isSpacer()) {
+        new_item = m_widget->domDocument().createElement(QStringLiteral("Spacer"));
     } else {
         new_item = m_widget->domDocument().createElement(QStringLiteral("Action"));
     }
