@@ -266,7 +266,7 @@ KKeySequenceWidget::KKeySequenceWidget(QWidget *parent)
 void KKeySequenceWidgetPrivate::init()
 {
     layout = new QHBoxLayout(q);
-    layout->setMargin(0);
+    layout->setContentsMargins(0, 0, 0, 0);
 
     keyButton = new KKeySequenceButton(this, q);
     keyButton->setFocusPolicy(Qt::StrongFocus);
@@ -462,7 +462,7 @@ bool KKeySequenceWidgetPrivate::conflictWithGlobalShortcuts(const QKeySequence &
 {
 #ifdef Q_OS_WIN
     //on windows F12 is reserved by the debugger at all times, so we can't use it for a global shortcut
-    if (KKeySequenceWidget::GlobalShortcuts && keySequence.toString().contains(QStringLiteral("F12"))) {
+    if (KKeySequenceWidget::GlobalShortcuts && keySequence.toString().contains(QLatin1String("F12"))) {
         QString title = i18n("Reserved Shortcut");
         QString message = i18n("The F12 key is reserved on Windows, so cannot be used for a global shortcut.\n"
                                "Please choose another one.");
@@ -632,7 +632,7 @@ void KKeySequenceWidgetPrivate::updateShortcutDisplay()
 {
     //empty string if no non-modifier was pressed
     QString s = keySequence.toString(QKeySequence::NativeText);
-    s.replace(QLatin1Char('&'), QStringLiteral("&&"));
+    s.replace(QLatin1Char('&'), QLatin1String("&&"));
 
     if (isRecording) {
         if (modifierKeys) {
@@ -640,43 +640,42 @@ void KKeySequenceWidgetPrivate::updateShortcutDisplay()
                 s.append(QLatin1Char(','));
             }
             if (modifierKeys & Qt::MetaModifier) {
-                s += KKeyServer::modToStringUser(Qt::MetaModifier) + QLatin1Char('+');
+                s += QKeySequence(Qt::MetaModifier).toString(QKeySequence::NativeText);
             }
 #if defined(Q_OS_MAC)
             if (modifierKeys & Qt::AltModifier) {
-                s += KKeyServer::modToStringUser(Qt::AltModifier) + QLatin1Char('+');
+                s += QKeySequence(Qt::AltModifier).toString(QKeySequence::NativeText);
             }
             if (modifierKeys & Qt::ControlModifier) {
-                s += KKeyServer::modToStringUser(Qt::ControlModifier) + QLatin1Char('+');
+                s += QKeySequence(Qt::ControlModifier).toString(QKeySequence::NativeText);
             }
 #else
             if (modifierKeys & Qt::ControlModifier) {
-                s += KKeyServer::modToStringUser(Qt::ControlModifier) + QLatin1Char('+');
+                s += QKeySequence(Qt::ControlModifier).toString(QKeySequence::NativeText);
             }
             if (modifierKeys & Qt::AltModifier) {
-                s += KKeyServer::modToStringUser(Qt::AltModifier) + QLatin1Char('+');
+                s += QKeySequence(Qt::AltModifier).toString(QKeySequence::NativeText);
             }
 #endif
             if (modifierKeys & Qt::ShiftModifier) {
-                s += KKeyServer::modToStringUser(Qt::ShiftModifier) + QLatin1Char('+');
+                s += QKeySequence(Qt::ShiftModifier).toString(QKeySequence::NativeText);
             }
             if (modifierKeys & Qt::KeypadModifier) {
-                s += KKeyServer::modToStringUser(Qt::KeypadModifier) + QLatin1Char('+');
+                s += QKeySequence(Qt::KeypadModifier).toString(QKeySequence::NativeText);
             }
 
         } else if (nKey == 0) {
             s = i18nc("What the user inputs now will be taken as the new shortcut", "Input");
         }
         //make it clear that input is still going on
-        s.append(QStringLiteral(" ..."));
+        s.append(QLatin1String(" ..."));
     }
 
     if (s.isEmpty()) {
         s = i18nc("No shortcut defined", "None");
     }
 
-    s.prepend(QLatin1Char(' '));
-    s.append(QLatin1Char(' '));
+    s = QLatin1Char(' ') + s + QLatin1Char(' ');
     keyButton->setText(s);
 }
 
