@@ -96,7 +96,7 @@ void KShortcutsEditor::clearCollections()
     d->delegate->contractAll();
     d->ui.list->clear();
     d->actionCollections.clear();
-    QTimer::singleShot(0, this, SLOT(resizeColumns()));
+    QTimer::singleShot(0, this, &KShortcutsEditor::resizeColumns);
 }
 
 void KShortcutsEditor::addCollection(KActionCollection *collection, const QString &title)
@@ -124,7 +124,7 @@ void KShortcutsEditor::addCollection(KActionCollection *collection, const QStrin
     QTreeWidgetItem *hier[3];
     hier[KShortcutsEditorPrivate::Root] = d->ui.list->invisibleRootItem();
     hier[KShortcutsEditorPrivate::Program] = d->findOrMakeItem(hier[KShortcutsEditorPrivate::Root], displayTitle);
-    hier[KShortcutsEditorPrivate::Action] = NULL;
+    hier[KShortcutsEditorPrivate::Action] = nullptr;
 
     // Set to remember which actions we have seen.
     QSet<QAction *> actionsSeen;
@@ -156,7 +156,7 @@ void KShortcutsEditor::addCollection(KActionCollection *collection, const QStrin
     // reenable updating
     setUpdatesEnabled(true);
 
-    QTimer::singleShot(0, this, SLOT(resizeColumns()));
+    QTimer::singleShot(0, this, &KShortcutsEditor::resizeColumns);
 }
 
 void KShortcutsEditor::clearConfiguration()
@@ -282,7 +282,7 @@ void KShortcutsEditor::setActionTypes(ActionTypes actionTypes)
 
 KShortcutsEditorPrivate::KShortcutsEditorPrivate(KShortcutsEditor *q)
     :   q(q),
-        delegate(0)
+        delegate(nullptr)
 {}
 
 void KShortcutsEditorPrivate::initGUI(KShortcutsEditor::ActionTypes types, KShortcutsEditor::LetterShortcuts allowLetterShortcuts)
@@ -290,7 +290,7 @@ void KShortcutsEditorPrivate::initGUI(KShortcutsEditor::ActionTypes types, KShor
     actionTypes = types;
 
     ui.setupUi(q);
-    q->layout()->setMargin(0);
+    q->layout()->setContentsMargins(0, 0, 0, 0);
     ui.searchFilter->searchLine()->setTreeWidget(ui.list); // Plug into search line
     ui.list->header()->setSectionResizeMode(QHeaderView::ResizeToContents);
     ui.list->header()->hideSection(ShapeGesture);  //mouse gestures didn't make it in time...
@@ -326,8 +326,8 @@ void KShortcutsEditorPrivate::initGUI(KShortcutsEditor::ActionTypes types, KShor
     QObject::connect(delegate, SIGNAL(shortcutChanged(QVariant,QModelIndex)),
                      q, SLOT(capturedShortcut(QVariant,QModelIndex)));
     //hide the editor widget chen its item becomes hidden
-    QObject::connect(ui.searchFilter->searchLine(), SIGNAL(hiddenChanged(QTreeWidgetItem*,bool)),
-                     delegate, SLOT(hiddenBySearchLine(QTreeWidgetItem*,bool)));
+    QObject::connect(ui.searchFilter->searchLine(), &KTreeWidgetSearchLine::hiddenChanged,
+                     delegate, &KShortcutsEditorDelegate::hiddenBySearchLine);
 
     ui.searchFilter->setFocus();
 }
@@ -362,7 +362,7 @@ bool KShortcutsEditorPrivate::addAction(QAction *action, QTreeWidgetItem *hier[]
     // If the action name starts with unnamed- spit out a warning and ignore
     // it. That name will change at will and will break loading and writing
     QString actionName = action->objectName();
-    if (actionName.isEmpty() || actionName.startsWith(QStringLiteral("unnamed-"))) {
+    if (actionName.isEmpty() || actionName.startsWith(QLatin1String("unnamed-"))) {
         qCritical() << "Skipping action without name " << action->text() << "," << actionName << "!";
         return false;
     }
@@ -429,7 +429,7 @@ KShortcutsEditorItem *KShortcutsEditorPrivate::itemFromIndex(QTreeWidget *const
     if (item && item->type() == ActionItem) {
         return static_cast<KShortcutsEditorItem *>(item);
     }
-    return 0;
+    return nullptr;
 }
 
 QTreeWidgetItem *KShortcutsEditorPrivate::findOrMakeItem(QTreeWidgetItem *parent, const QString &name)
@@ -478,7 +478,7 @@ void KShortcutsEditorPrivate::changeKeyShortcut(KShortcutsEditorItem *item, uint
     }
 
     item->setKeySequence(column, capture);
-    q->keyChange();
+    emit q->keyChange();
     //force view update
     item->setText(column, capture.toString(QKeySequence::NativeText));
 }
@@ -750,7 +750,7 @@ void KShortcutsEditorPrivate::printShortcuts() const
             QVariant data = editoritem->data(Name, Qt::DisplayRole);
             table->cellAt(currow, 0).firstCursorPosition().insertText(data.toString());
 
-            QTextTable *shortcutTable = 0;
+            QTextTable *shortcutTable = nullptr;
             for (int k = 0; k < shortcutTitleToColumn.count(); k++) {
                 data = editoritem->data(shortcutTitleToColumn.at(k).second, Qt::DisplayRole);
                 QString key = data.value<QKeySequence>().toString();
