@@ -22,25 +22,28 @@
     the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
     Boston, MA 02110-1301, USA.
 */
+#include "config-xmlgui.h"
 
 #include "kshortcutsdialog_p.h"
+#include "debug.h"
 
 #include <QAction>
 #include <QTreeWidgetItem>
-#include <QDebug>
 
 #if 0
 #include <kgesturemap.h>
 #endif
 
-#include <kglobalaccel.h>
+#if HAVE_GLOBALACCEL
+# include <kglobalaccel.h>
+#endif
 
 KShortcutsEditorItem::KShortcutsEditorItem(QTreeWidgetItem *parent, QAction *action)
     : QTreeWidgetItem(parent, ActionItem)
     , m_action(action)
     , m_isNameBold(false)
-    , m_oldLocalShortcut(0)
-    , m_oldGlobalShortcut(0)
+    , m_oldLocalShortcut(nullptr)
+    , m_oldGlobalShortcut(nullptr)
 #if 0
     , m_oldShapeGesture(0)
     , m_oldRockerGesture(0)
@@ -50,7 +53,7 @@ KShortcutsEditorItem::KShortcutsEditorItem(QTreeWidgetItem *parent, QAction *act
     m_id = m_action->objectName();
     m_actionNameInTable = i18nc("@item:intable Action name in shortcuts configuration", "%1", KLocalizedString::removeAcceleratorMarker(m_action->text()));
     if (m_actionNameInTable.isEmpty()) {
-        qWarning() << "Action without text!" << m_action->objectName();
+        qCWarning(DEBUG_KXMLGUI) << "Action without text!" << m_action->objectName();
         m_actionNameInTable = m_id;
     }
 
@@ -107,7 +110,6 @@ QVariant KShortcutsEditorItem::data(int column, int role) const
         } else {
             return QIcon();
         }
-        break;
     case Qt::WhatsThisRole:
         return m_action->whatsThis();
     case Qt::ToolTipRole:
@@ -129,12 +131,14 @@ QVariant KShortcutsEditorItem::data(int column, int role) const
         case LocalAlternate:
             return !m_action->property("isShortcutConfigurable").isValid()
                    || m_action->property("isShortcutConfigurable").toBool();
+#if HAVE_GLOBALACCEL
         case GlobalPrimary:
         case GlobalAlternate:
             if (!KGlobalAccel::self()->hasShortcut(m_action)) {
                 return false;
             }
             return true;
+#endif
         default:
             return false;
         }
@@ -166,17 +170,21 @@ QVariant KShortcutsEditorItem::data(int column, int role) const
 
     case DefaultShortcutRole: {
         QList<QKeySequence> defaultShortcuts = m_action->property("defaultShortcuts").value<QList<QKeySequence> >();
+#if HAVE_GLOBALACCEL
         QList<QKeySequence> defaultGlobalShortcuts = KGlobalAccel::self()->defaultShortcut(m_action);
+#endif
 
         switch (column) {
         case LocalPrimary:
             return primarySequence(defaultShortcuts);
         case LocalAlternate:
             return alternateSequence(defaultShortcuts);
+#if HAVE_GLOBALACCEL
         case GlobalPrimary:
             return primarySequence(defaultGlobalShortcuts);
         case GlobalAlternate:
             return alternateSequence(defaultGlobalShortcuts);
+#endif
 #if 0
         case ShapeGesture: {
             QVariant ret;
@@ -196,7 +204,7 @@ QVariant KShortcutsEditorItem::data(int column, int role) const
         }
     }
     case ObjectRole:
-        return qVariantFromValue((QObject *)m_action);
+        return QVariant::fromValue(static_cast<QObject *>(m_action));
 
     default:
         break;
@@ -214,17 +222,21 @@ bool KShortcutsEditorItem::operator<(const QTreeWidgetItem &other) const
 QKeySequence KShortcutsEditorItem::keySequence(uint column) const
 {
     QList<QKeySequence> shortcuts = m_action->shortcuts();
+#if HAVE_GLOBALACCEL
     QList<QKeySequence> globalShortcuts = KGlobalAccel::self()->shortcut(m_action);
+#endif
 
     switch (column) {
     case LocalPrimary:
         return primarySequence(shortcuts);
     case LocalAlternate:
         return alternateSequence(shortcuts);
+#if HAVE_GLOBALACCEL
     case GlobalPrimary:
         return primarySequence(globalShortcuts);
     case GlobalAlternate:
         return alternateSequence(globalShortcuts);
+#endif
     default:
         return QKeySequence();
     }
@@ -233,12 +245,15 @@ QKeySequence KShortcutsEditorItem::keySequence(uint column) const
 void KShortcutsEditorItem::setKeySequence(uint column, const QKeySequence &seq)
 {
     QList<QKeySequence> ks;
+#if HAVE_GLOBALACCEL
     if (column == GlobalPrimary || column == GlobalAlternate) {
         ks = KGlobalAccel::self()->shortcut(m_action);
         if (!m_oldGlobalShortcut) {
             m_oldGlobalShortcut = new QList<QKeySequence>(ks);
         }
-    } else {
+    } else
+#endif
+    {
         ks = m_action->shortcuts();
         if (!m_oldLocalShortcut) {
             m_oldLocalShortcut = new QList<QKeySequence>(ks);
@@ -264,9 +279,13 @@ void KShortcutsEditorItem::setKeySequence(uint column, const QKeySequence &seq)
     }
 
     //avoid also setting the default shortcut - what we are setting here is custom by definition
+#if HAVE_GLOBALACCEL
     if (column == GlobalPrimary || column == GlobalAlternate) {
         KGlobalAccel::self()->setShortcut(m_action, ks, KGlobalAccel::NoAutoloading);
-    } else {
+
+    } else
+#endif
+    {
         m_action->setShortcuts(ks);
     }
 
@@ -302,12 +321,14 @@ void KShortcutsEditorItem::updateModified()
 {
     if (m_oldLocalShortcut && *m_oldLocalShortcut == m_action->shortcuts()) {
         delete m_oldLocalShortcut;
-        m_oldLocalShortcut = 0;
+        m_oldLocalShortcut = nullptr;
     }
+#if HAVE_GLOBALACCEL
     if (m_oldGlobalShortcut && *m_oldGlobalShortcut == KGlobalAccel::self()->shortcut(m_action)) {
         delete m_oldGlobalShortcut;
-        m_oldGlobalShortcut = 0;
+        m_oldGlobalShortcut = nullptr;
     }
+#endif
 #if 0
     if (m_oldShapeGesture && *m_oldShapeGesture == KGestureMap::self()->shapeGesture(m_action)) {
         delete m_oldShapeGesture;
@@ -335,6 +356,7 @@ bool KShortcutsEditorItem::isModified(uint column) const
         } else {
             return alternateSequence(*m_oldLocalShortcut) != alternateSequence(m_action->shortcuts());
         }
+#if HAVE_GLOBALACCEL
     case GlobalPrimary:
     case GlobalAlternate:
         if (!m_oldGlobalShortcut) {
@@ -345,6 +367,7 @@ bool KShortcutsEditorItem::isModified(uint column) const
         } else {
             return alternateSequence(*m_oldGlobalShortcut) != alternateSequence(KGlobalAccel::self()->shortcut(m_action));
         }
+#endif
 #if 0
     case ShapeGesture:
         return static_cast<bool>(m_oldShapeGesture);
@@ -361,7 +384,7 @@ void KShortcutsEditorItem::undo()
 #ifndef NDEBUG
 #if 0
     if (m_oldLocalShortcut || m_oldGlobalShortcut || m_oldShapeGesture || m_oldRockerGesture) {
-        //qDebug() << "Undoing changes for " << data(Name, Qt::DisplayRole).toString();
+        //qCDebug(DEBUG_KXMLGUI) << "Undoing changes for " << data(Name, Qt::DisplayRole).toString();
     }
 #endif
 #endif
@@ -370,9 +393,11 @@ void KShortcutsEditorItem::undo()
         m_action->setShortcuts(*m_oldLocalShortcut);
     }
 
+#if HAVE_GLOBALACCEL
     if (m_oldGlobalShortcut) {
         KGlobalAccel::self()->setShortcut(m_action, *m_oldGlobalShortcut, KGlobalAccel::NoAutoloading);
     }
+#endif
 
 #if 0
     if (m_oldShapeGesture) {
@@ -394,15 +419,15 @@ void KShortcutsEditorItem::commit()
 #ifndef NDEBUG
 #if 0
     if (m_oldLocalShortcut || m_oldGlobalShortcut || m_oldShapeGesture || m_oldRockerGesture) {
-        //qDebug() << "Committing changes for " << data(Name, Qt::DisplayRole).toString();
+        //qCDebug(DEBUG_KXMLGUI) << "Committing changes for " << data(Name, Qt::DisplayRole).toString();
     }
 #endif
 #endif
 
     delete m_oldLocalShortcut;
-    m_oldLocalShortcut = 0;
+    m_oldLocalShortcut = nullptr;
     delete m_oldGlobalShortcut;
-    m_oldGlobalShortcut = 0;
+    m_oldGlobalShortcut = nullptr;
 #if 0
     delete m_oldShapeGesture;
     m_oldShapeGesture = 0;
