@@ -36,11 +36,11 @@
 #include <QMimeData>
 #include <QDrag>
 #include <QMouseEvent>
-#include <QToolButton>
 #include <QDomElement>
+#ifdef QT_DBUS_LIB
 #include <QDBusConnection>
 #include <QDBusMessage>
-#include <QDebug>
+#endif
 
 #include <kauthorized.h>
 #include <kconfig.h>
@@ -252,16 +252,16 @@ void KToolBar::Private::init(bool readConfig, bool _isMainToolBar)
 
     if (q->mainWindow()) {
         // Get notified when settings change
-        connect(q, SIGNAL(allowedAreasChanged(Qt::ToolBarAreas)),
-                q->mainWindow(), SLOT(setSettingsDirty()));
-        connect(q, SIGNAL(iconSizeChanged(QSize)),
-                q->mainWindow(), SLOT(setSettingsDirty()));
-        connect(q, SIGNAL(toolButtonStyleChanged(Qt::ToolButtonStyle)),
-                q->mainWindow(), SLOT(setSettingsDirty()));
-        connect(q, SIGNAL(movableChanged(bool)),
-                q->mainWindow(), SLOT(setSettingsDirty()));
-        connect(q, SIGNAL(orientationChanged(Qt::Orientation)),
-                q->mainWindow(), SLOT(setSettingsDirty()));
+        connect(q, &QToolBar::allowedAreasChanged,
+                q->mainWindow(), &KMainWindow::setSettingsDirty);
+        connect(q, &QToolBar::iconSizeChanged,
+                q->mainWindow(), &KMainWindow::setSettingsDirty);
+        connect(q, &QToolBar::toolButtonStyleChanged,
+                q->mainWindow(), &KMainWindow::setSettingsDirty);
+        connect(q, &QToolBar::movableChanged,
+                q->mainWindow(), &KMainWindow::setSettingsDirty);
+        connect(q, &QToolBar::orientationChanged,
+                q->mainWindow(), &KMainWindow::setSettingsDirty);
     }
 
     if (!KAuthorized::authorize(QStringLiteral("movable_toolbars"))) {
@@ -272,13 +272,15 @@ void KToolBar::Private::init(bool readConfig, bool _isMainToolBar)
 
     q->toggleViewAction()->setEnabled(KAuthorized::authorizeAction(QStringLiteral("options_show_toolbar")));
 
-    connect(q, SIGNAL(movableChanged(bool)),
-            q, SLOT(slotMovableChanged(bool)));
+    connect(q, &QToolBar::movableChanged,
+            q, &KToolBar::slotMovableChanged);
 
     q->setAcceptDrops(true);
 
+#ifdef QT_DBUS_LIB
     QDBusConnection::sessionBus().connect(QString(), QStringLiteral("/KToolBar"), QStringLiteral("org.kde.KToolBar"),
                                           QStringLiteral("styleChanged"), q, SLOT(slotAppearanceChanged()));
+#endif
     connect(KIconLoader::global(), SIGNAL(iconLoaderSettingsChanged()),
             q, SLOT(slotAppearanceChanged()));
 }
@@ -348,7 +350,7 @@ QMenu *KToolBar::Private::contextMenu(const QPoint &globalPos)
             avSizes = theme->querySizes(isMainToolBar ? KIconLoader::MainToolbar : KIconLoader::Toolbar);
         }
 
-        qSort(avSizes);
+        std::sort(avSizes.begin(), avSizes.end());
 
         if (avSizes.count() < 10) {
             // Fixed or threshold type icons
@@ -472,11 +474,11 @@ void KToolBar::Private::adjustSeparatorVisibility()
 Qt::ToolButtonStyle KToolBar::Private::toolButtonStyleFromString(const QString &_style)
 {
     QString style = _style.toLower();
-    if (style == QStringLiteral("textbesideicon") || style == QLatin1String("icontextright")) {
+    if (style == QLatin1String("textbesideicon") || style == QLatin1String("icontextright")) {
         return Qt::ToolButtonTextBesideIcon;
-    } else if (style == QStringLiteral("textundericon") || style == QLatin1String("icontextbottom")) {
+    } else if (style == QLatin1String("textundericon") || style == QLatin1String("icontextbottom")) {
         return Qt::ToolButtonTextUnderIcon;
-    } else if (style == QStringLiteral("textonly")) {
+    } else if (style == QLatin1String("textonly")) {
         return Qt::ToolButtonTextOnly;
     } else {
         return Qt::ToolButtonIconOnly;
@@ -501,11 +503,11 @@ QString KToolBar::Private::toolButtonStyleToString(Qt::ToolButtonStyle style)
 Qt::ToolBarArea KToolBar::Private::positionFromString(const QString &position)
 {
     Qt::ToolBarArea newposition = Qt::TopToolBarArea;
-    if (position == QStringLiteral("left")) {
+    if (position == QLatin1String("left")) {
         newposition = Qt::LeftToolBarArea;
-    } else if (position == QStringLiteral("bottom")) {
+    } else if (position == QLatin1String("bottom")) {
         newposition = Qt::BottomToolBarArea;
-    } else if (position == QStringLiteral("right")) {
+    } else if (position == QLatin1String("right")) {
         newposition = Qt::RightToolBarArea;
     }
     return newposition;
@@ -615,7 +617,7 @@ void KToolBar::Private::slotContextAboutToShow()
         kmw->setupToolbarMenuActions();
         // Only allow hiding a toolbar if the action is also plugged somewhere else (e.g. menubar)
         QAction *tbAction = kmw->toolBarMenuAction();
-        if (!q->toolBarsLocked() && tbAction && tbAction->associatedWidgets().count() > 0) {
+        if (!q->toolBarsLocked() && tbAction && !tbAction->associatedWidgets().isEmpty()) {
             context->addAction(tbAction);
         }
     }
@@ -728,7 +730,7 @@ void KToolBar::Private::slotContextShowText()
     }
     if (filename.isEmpty()) {
         componentName = QCoreApplication::applicationName();
-        filename = componentName + QStringLiteral("ui.rc");
+        filename = componentName + QLatin1String("ui.rc");
     }
 
     // Save the priority state of the action
@@ -809,7 +811,7 @@ KToolBar::KToolBar(const QString &objectName, QWidget *parent, bool readConfig)
     setObjectName(objectName);
     // mainToolBar -> isMainToolBar = true  -> buttonStyle is configurable
     // others      -> isMainToolBar = false -> ### hardcoded default for buttonStyle !!! should be configurable? -> hidden key added
-    d->init(readConfig, objectName == QStringLiteral("mainToolBar"));
+    d->init(readConfig, (objectName == QLatin1String("mainToolBar")));
 
     // KToolBar is auto-added to the top area of the main window if parent is a QMainWindow
     if (QMainWindow *mw = qobject_cast<QMainWindow *>(parent)) {
@@ -960,7 +962,7 @@ void KToolBar::loadState(const QDomElement &element)
         bool newLine = false;
         QString attrNewLine = element.attribute(QStringLiteral("newline")).toLower();
         if (!attrNewLine.isEmpty()) {
-            newLine = attrNewLine == QStringLiteral("true");
+            newLine = (attrNewLine == QLatin1String("true"));
         }
         if (newLine && mw) {
             mw->insertToolBarBreak(this);
@@ -988,7 +990,7 @@ void KToolBar::loadState(const QDomElement &element)
     {
         QString attrHidden = element.attribute(QStringLiteral("hidden")).toLower();
         if (!attrHidden.isEmpty()) {
-            hidden = attrHidden  == QStringLiteral("true");
+            hidden = (attrHidden == QLatin1String("true"));
         }
     }
 
@@ -1245,7 +1247,7 @@ void KToolBar::mouseMoveEvent(QMouseEvent *event)
 
     drag->setMimeData(mimeData);
 
-    Qt::DropAction dropAction = drag->start(Qt::MoveAction);
+    Qt::DropAction dropAction = drag->exec(Qt::MoveAction);
 
     if (dropAction == Qt::MoveAction)
         // Only remove from this toolbar if it was moved to another toolbar
@@ -1399,8 +1401,10 @@ bool KToolBar::toolBarsLocked()
 
 void KToolBar::emitToolbarStyleChanged()
 {
+#ifdef QT_DBUS_LIB
     QDBusMessage message = QDBusMessage::createSignal(QStringLiteral("/KToolBar"), QStringLiteral("org.kde.KToolBar"), QStringLiteral("styleChanged"));
     QDBusConnection::sessionBus().send(message);
+#endif
 }
 
 #include "moc_ktoolbar.cpp"
